@@ -36,7 +36,7 @@ namespace KContacts
 class Addressee;
 class ContactGroup;
 }
-namespace KLDAPWidgets
+namespace KLDAPCore
 {
 class LdapClientSearch;
 }
@@ -117,7 +117,7 @@ public:
 
     void updateBalooBlackList();
     void updateCompletionOrder();
-    [[nodiscard]] KLDAPWidgets::LdapClientSearch *ldapSearch() const;
+    [[nodiscard]] KLDAPCore::LdapClientSearch *ldapSearch() const;
 
     void setShowRecentAddresses(bool b);
     [[nodiscard]] bool showRecentAddresses() const;
@@ -177,19 +177,16 @@ protected:
      */
     void mouseReleaseEvent(QMouseEvent *) override;
 
-#ifndef QT_NO_DRAGANDDROP
     /**
      * Reimplemented for smart insertion of dragged email addresses.
      */
     void dropEvent(QDropEvent *) override;
-#endif
 
     /**
      * Reimplemented for internal reasons.
      */
     void keyPressEvent(QKeyEvent *) override;
 
-#ifndef QT_NO_CONTEXTMENU
     /**
      * Reimplemented for subclass access to menu
      */
@@ -201,7 +198,6 @@ protected:
      * See QLineEdit::contextMenuEvent().
      */
     void contextMenuEvent(QContextMenuEvent *) override;
-#endif
 
     void insertEmails(const QStringList &emails);
     void loadContacts();
